#!/usr/bin/env python3
# coding: utf-8

"""
Deprecated. This module will be removed on ver 0.6.0.
"""

from joker.flasky.auth import HashedPassword

__all__ = []
__deprecated__ = [HashedPassword]
